@@ -7,13 +7,11 @@ App::Parcimonie::Applet - systray applet object monitoring parcimonie's activiti
 =cut
 
 package App::Parcimonie::Applet;
-use Any::Moose;
+use Moo;
+use MooX::late;
 with 'App::Parcimonie::Role::HasEncoding';
 
-our $VERSION = '0.7'; # VERSION
-
 use 5.10.0;
-use namespace::autoclean;
 
 use Encode;
 
@@ -164,7 +162,7 @@ b) the "Artistic License" which comes with Perl.
     $icon->signal_connect('button-press-event' => sub {
         my $ticon = shift;
         my $event = shift;
-        return unless $event->button->{button} == 1;
+        return unless $event->button == 1;
         if ($self->monitorwin->get_visible) {
             $self->monitorwin->hide;
         }
@@ -248,7 +246,7 @@ sub append_mesg {
     my $self = shift;
     my $mesg = shift;
     my $buffer = $self->logbuffer;
-    $buffer->insert($buffer->get_end_iter, $mesg . "\n");
+    $buffer->insert($buffer->get_end_iter, $mesg . "\n", -1);
 }
 
 sub signal_fetch_begin_cb {
@@ -261,7 +259,7 @@ sub signal_fetch_begin_cb {
     );
     $self->debug($mesg);
     $self->statusicon->set_from_stock('gtk-refresh');
-    $self->statusicon->set_tooltip($mesg);
+    $self->statusicon->set_tooltip_text($mesg);
     $self->append_mesg($mesg);
     $self->statusicon->set_visible(TRUE);
 }
@@ -292,7 +290,7 @@ sub signal_fetch_end_cb {
 
     $self->debug($mesg);
     $self->statusicon->set_from_stock($new_pixmap);
-    $self->statusicon->set_tooltip($mesg);
+    $self->statusicon->set_tooltip_text($mesg);
     $self->append_mesg($mesg);
     $self->statusicon->set_visible(TRUE);
     Glib::Timeout->add(
@@ -304,7 +302,7 @@ sub signal_fetch_end_cb {
 sub now_resting {
     my $self = shift;
     $self->statusicon->set_from_stock('gtk-media-pause');
-    $self->statusicon->set_tooltip($self->encoding->decode(
+    $self->statusicon->set_tooltip_text($self->encoding->decode(
         gettext('Having a rest.')
     ));
     $self->statusicon->set_visible(TRUE);
@@ -312,5 +310,4 @@ sub now_resting {
     return;
 }
 
-no Any::Moose;
 1;
