@@ -9,11 +9,10 @@ Have a look to App::Parcimonie::Daemon for a full-blown real life usage example.
 =cut
 
 package App::Parcimonie::GnuPG::Interface;
-use Any::Moose;
+use Moo;
+use MooX::late;
 extends 'GnuPG::Interface';
 
-our $VERSION = '0.7'; # VERSION
-
 use namespace::autoclean;
 use Carp;
 use File::Which qw{which};
@@ -94,5 +93,5 @@ sub get_public_keys_hex {
 
 }
 
-no Any::Moose;
+no Moo;
 1; # End of App::Parcimonie::GnuPG::Interface
