@@ -4,23 +4,17 @@ App::Parcimonie::Role::HasCodeset - role to get the codeset being used
 
 =head1 SYNOPSIS
 
-    use MooseX::Declare;
-    class App::Parcimonie::Daemon with App::Parcimonie::Role::HasCodeset {
-      ...
-    }
-
-    See App::Parcimonie::Daemon for a real-life usage example.
+    See App::Parcimonie::Role::HasEncoding source code.
 
 =cut
 
 package App::Parcimonie::Role::HasCodeset;
-use Any::Moose 'Role';
 
-our $VERSION = '0.7'; # VERSION
-
-use namespace::autoclean;
 use Try::Tiny;
 
+use Moo::Role; # Moo::Role exports all methods declared after it's "use"'d
+use MooX::late;
+
 has 'codeset'  => (
     isa        => 'Str',
     is         => 'ro',
@@ -39,5 +33,5 @@ sub _build_codeset {
     $codeset;
 }
 
-no Any::Moose 'Role';
+no Moo::Role;
 1; # End of App::Parcimonie::Role::HasCodeset
